==> estateplat-common-1.2.3-20180122.024348-19-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtLog.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 日志对象
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/12/6
 */
@Table(name = "bdc_xt_log")
public class BdcXtLog implements Serializable {
    @Id
    private String logid;
    //用户名
    private String username;
    //用户Id
    private String userid;
    //操作时间
    private Date czrq;
    //操作路径
    private String controller;
    //操作内容参数
    private String parmjson;
    //ip
    private String ip;
    //mac
    private String mac;
    //计算机名
    private String computername;
    //操作原因
    private String reason;
    //工作流id
    private String wiid;

    public String getLogid() {
        return logid;
    }

    public void setLogid(String logid) {
        this.logid = logid;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getUserid() {
        return userid;
    }

    public void setUserid(String userid) {
        this.userid = userid;
    }

    public Date getCzrq() {
        return czrq;
    }

    public void setCzrq(Date czrq) {
        this.czrq = czrq;
    }

    public String getController() {
        return controller;
    }

    public void setController(String controller) {
        this.controller = controller;
    }

    public String getParmjson() {
        return parmjson;
    }

    public void setParmjson(String parmjson) {
        this.parmjson = parmjson;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getMac() {
        return mac;
    }

    public void setMac(String mac) {
        this.mac = mac;
    }

    public String getComputername() {
        return computername;
    }

    public void setComputername(String computername) {
        this.computername = computername;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }
}

==> estateplat-common-1.2.4-20210423.031343-733-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtLog.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 日志对象
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/12/6
 */
@Table(name = "bdc_xt_log")
public class BdcXtLog implements Serializable {
    @Id
    private String logid;
    //用户名
    private String username;
    //用户Id
    private String userid;
    //操作时间
    private Date czrq;
    //操作路径
    private String controller;
    //操作内容参数
    private String parmjson;
    //ip
    private String ip;
    //mac
    private String mac;
    //计算机名
    private String computername;
    //操作原因
    private String reason;
    //操作结果
    private String result;
    //工作流id
    private String wiid;

    public String getLogid() {
        return logid;
    }

    public void setLogid(String logid) {
        this.logid = logid;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getUserid() {
        return userid;
    }

    public void setUserid(String userid) {
        this.userid = userid;
    }

    public Date getCzrq() {
        return czrq;
    }

    public void setCzrq(Date czrq) {
        this.czrq = czrq;
    }

    public String getController() {
        return controller;
    }

    public void setController(String controller) {
        this.controller = controller;
    }

    public String getParmjson() {
        return parmjson;
    }

    public void setParmjson(String parmjson) {
        this.parmjson = parmjson;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getMac() {
        return mac;
    }

    public void setMac(String mac) {
        this.mac = mac;
    }

    public String getComputername() {
        return computername;
    }

    public void setComputername(String computername) {
        this.computername = computername;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getResult() {
        return result;
    }

    public void setResult(String result) {
        this.result = result;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }
}
